==> hs-tar-0.3.1.0_1.tbz: lib/ghc-7.0.3/cabal/tar-0.3.1.0/register.sh <==
#!/bin/sh
echo 'name: tar
version: 0.3.1.0
id: tar-0.3.1.0-7c4cf34ad123bdf5b9439a9772f894e5

license: BSD3
copyright: 2007 Bjorn Bringert <bjorn@bringert.net>
           2008-2009 Duncan Coutts <duncan@haskell.org>
maintainer: Duncan Coutts <duncan@haskell.org>
stability:
homepage:
package-url:
description: This library is for working with \"@.tar@\" archive files. It
             can read and write a range of common variations of archive
             format including V7, USTAR, POSIX and GNU formats. It provides
             support for packing and unpacking portable archives. This
             makes it suitable for distribution but not backup because
             details like file ownership and exact permissions are not
             preserved.
category: Codec
author: Bjorn Bringert <bjorn@bringert.net>
        Duncan Coutts <duncan@haskell.org>
exposed: True
exposed-modules: Codec.Archive.Tar Codec.Archive.Tar.Entry
                 Codec.Archive.Tar.Check
hidden-modules: Codec.Archive.Tar.Types Codec.Archive.Tar.Read
                Codec.Archive.Tar.Write Codec.Archive.Tar.Pack
                Codec.Archive.Tar.Unpack
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/tar-0.3.1.0
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/tar-0.3.1.0
              /usr/local/lib
hs-libraries: HStar-0.3.1.0
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         bytestring-0.9.1.10-8fbcae7fd1f192307195284611c786a2
         directory-1.1.0.0-ccdcf043bf8bcec9518fbfad880579a5
         filepath-1.2.0.0-679ac50c41ba31bfc69abf444d9852e4
         old-time-1.0.0.6-37d6575186c36059fbc372c289dbddd4
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/tar-0.3.1.0/html/tar.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/tar-0.3.1.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-tar-0.3.2.0.tbz: lib/ghc-7.0.4/cabal/tar-0.3.2.0/register.sh <==
#!/bin/sh
echo 'name: tar
version: 0.3.2.0
id: tar-0.3.2.0-d5e7a1adaecebf652f0c5329cb9f6f4a

license: BSD3
copyright: 2007 Bjorn Bringert <bjorn@bringert.net>
           2008-2012 Duncan Coutts <duncan@community.haskell.org>
maintainer: Duncan Coutts <duncan@community.haskell.org>
stability:
homepage:
package-url:
description: This library is for working with \"@.tar@\" archive files. It
             can read and write a range of common variations of archive
             format including V7, USTAR, POSIX and GNU formats. It provides
             support for packing and unpacking portable archives. This
             makes it suitable for distribution but not backup because
             details like file ownership and exact permissions are not
             preserved.
category: Codec
author: Bjorn Bringert <bjorn@bringert.net>
        Duncan Coutts <duncan@community.haskell.org>
exposed: True
exposed-modules: Codec.Archive.Tar Codec.Archive.Tar.Entry
                 Codec.Archive.Tar.Check
hidden-modules: Codec.Archive.Tar.Types Codec.Archive.Tar.Read
                Codec.Archive.Tar.Write Codec.Archive.Tar.Pack
                Codec.Archive.Tar.Unpack
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/tar-0.3.2.0
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/tar-0.3.2.0
              /usr/local/lib
hs-libraries: HStar-0.3.2.0
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         bytestring-0.9.1.10-8fbcae7fd1f192307195284611c786a2
         directory-1.1.0.0-ccdcf043bf8bcec9518fbfad880579a5
         filepath-1.2.0.0-679ac50c41ba31bfc69abf444d9852e4
         old-time-1.0.0.6-37d6575186c36059fbc372c289dbddd4
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/tar-0.3.2.0/html/tar.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/tar-0.3.2.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
